from typing import Union

from csp_cbc_auth.cbc.session import CBCSession
from psc_auth_integration.entities.auth_user_session import AuthUserSession

from cds_configuration_service.api_clients.base_api_class import ConfigurationServiceBaseClass


class ConfigurationServiceHealthApi(ConfigurationServiceBaseClass):
    """
    This class contains methods for performing health checks on the configuration service.
    """

    def __init__(self, session: Union[AuthUserSession, CBCSession]):
        super().__init__(session)
        self.health_check_url = f'{self.configuration_service_base_url}/v1/health_check'

    def get_health_check(self) -> dict:
        """
        Performs a health check by calling the /health_check endpoint.
        :return: The JSON response as a dictionary.
        """
        response = self.get(url=self.health_check_url)
        return response.json()
