import os

import pytest

from cds_configuration_service.api_clients.global_configuration_service_v1 import GlobalConfigurationServiceV1Api
from cds_configuration_service.api_clients.custom_configuration_service_v1 import CustomConfigurationServiceV1Api
from cds_configuration_service.tests.utils.auth import CDSSession


pytest_plugins = []
if os.environ.get('USE_OWNERSHIP_PLUGIN', False):
    pytest_plugins.append('cds_configuration_service.tests.plugins.ownership_plugin')


@pytest.fixture()
def auth_session() -> CDSSession:
    """
    Create new CSR auth session
    :return: CDSSession
    """
    return CDSSession()


@pytest.fixture()
def csr_auth_session() -> CDSSession:
    """
    Create new CSR auth session
    :return: CDSSession
    """
    return CDSSession(is_csr=True)


@pytest.fixture()
def global_configuration_service_v1_api(csr_auth_session) -> GlobalConfigurationServiceV1Api:
    """
    Content Reporting V1 API wrapper
    :param csr_auth_session:
    :return:
    """
    return GlobalConfigurationServiceV1Api(csr_auth_session.session)

@pytest.fixture()
def custom_configuration_service_v1_api(csr_auth_session) -> CustomConfigurationServiceV1Api:
    """
    Content Reporting V1 API wrapper
    :param csr_auth_session:
    :return:
    """
    return CustomConfigurationServiceV1Api(csr_auth_session.session)
